/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */

/** \defgroup mrpt_hmtslam_grp [mrpt-hmtslam]

<small> <a href="index.html#libs">Back to list of all libraries</a> | <a href="modules.html" >See all modules</a> </small>
<br>

<h2>Library <code>mrpt-hmtslam</code></h2>
<hr>

This library includes an implementation of the HMT-SLAM framework. 
See the list of classes in mrpt::hmtslam, and the application hmt-slam-gui.

<b>NOTE:</b> For new designs, it is recommended to try the \ref mrpt_srba_grp "[srba]" library instead.


*/

